==> profile-python-0.0.2.tar.gz: profile-python-0.0.2/README.md <==
# Profile Python

[![CI](https://github.com/joaolfp/profile-python/actions/workflows/CI.yml/badge.svg)](https://github.com/joaolfp/profile-python/actions/workflows/CI.yml)
[![codecov](https://codecov.io/gh/heroesofcode/profile-python/branch/master/graph/badge.svg?token=TDUTA1UY6N)](https://codecov.io/gh/heroesofcode/profile-python)
[![GitHub release (latest by date)](https://img.shields.io/github/v/release/joaolfp/profile-python)](https://github.com/joaolfp/profile-python/releases)
[![GitHub](https://img.shields.io/github/license/joaolfp/profile-python)](https://github.com/joaolfp/profile-python/blob/master/LICENSE)

## Overview
Profile python is a script for you to view your data and github repositories.

## Installing
```
python -m profile_python
```

## What to use?
<img src="https://github.com/joaolfp/profile-python/blob/master/.github/assets/example-repo.gif" width="550px" height="700px">

## Author
Coded by [João Lucas](https://github.com/joaolfp)

## License

```
MIT License

Copyright (c) 2021 João Lucas

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

==> profile-python-0.1.4.tar.gz: profile-python-0.1.4/README.md <==
# Profile Python

[![CI](https://github.com/joaolfp/profile-python/actions/workflows/CI.yml/badge.svg)](https://github.com/joaolfp/profile-python/actions/workflows/CI.yml)
[![codecov](https://codecov.io/gh/heroesofcode/profile-python/branch/master/graph/badge.svg?token=TDUTA1UY6N)](https://codecov.io/gh/heroesofcode/profile-python)
[![GitHub release (latest by date)](https://img.shields.io/github/v/release/joaolfp/profile-python)](https://github.com/joaolfp/profile-python/releases)
[![PyPI](https://img.shields.io/pypi/v/profile-python)](https://pypi.org/project/profile-python/)
[![GitHub](https://img.shields.io/github/license/joaolfp/profile-python)](https://github.com/joaolfp/profile-python/blob/master/LICENSE)

## Overview
Profile python is a script for you to view your data and github repositories.

## Installing
Install with pip or your favorite PyPi package manager:
```
python3 -m pip install profile-python
```

After installing build on terminal:
```
python3 -m profile_python
```

## What to use?
<img src="https://github.com/joaolfp/profile-python/blob/master/.github/assets/example-repo.gif" width="550px" height="700px">

## Author
Coded by [João Lucas](https://github.com/joaolfp)

## License

```
MIT License

Copyright (c) 2021 João Lucas

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
